Welcome to jaraco.stream documentation!
=======================================

.. toctree::
   :maxdepth: 1

   history


.. automodule:: jaraco.stream
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

